| bind_as_struct | R Documentation |
Given a set of lists/dataframes, attempt to join them as a dataframe with field types matching the specified template. The default approach uses all fields present in the input lists, while the strict mode ensures that the template fields and only the template fields are present.
bind_as_struct(template, ..., .list = NULL, strict = FALSE)
template |
A named list to use as a template. |
... |
The lists to join |
.list |
A pre-built list of frames to join, as an alternative to |
strict |
Use all and only the fields in the template. Default: FALSE |
A dataframe containing the combined inputs.
bind_as_struct(list("a" = character(0)), list("a" = 1), list("a" = "a"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.